<?php

namespace BS\StickyFirstPost;

use XF\AddOn\AbstractSetup;
use XF\AddOn\StepRunnerInstallTrait;
use XF\AddOn\StepRunnerUninstallTrait;
use XF\AddOn\StepRunnerUpgradeTrait;
use XF\Db\Schema\Alter;

class Setup extends AbstractSetup
{
	use StepRunnerInstallTrait;
	use StepRunnerUpgradeTrait;
	use StepRunnerUninstallTrait;

    // ################################ INSTALLATION ####################

	public function installStep1()
	{
        $sm = $this->schemaManager();

        foreach ($this->getAlterTables() AS $tableName => $closure)
        {
            $sm->alterTable($tableName, $closure[0]);
        }
	}

    // ################################ UPGRADE 1.0.1 ####################

    public function upgrade1000170Step1()
    {
        $this->schemaManager()->alterTable('xf_forum', function(Alter $table)
        {
            $table->renameColumn('is_sticky_first_post', 'bs_is_sticky_first_post');
        });

        $this->schemaManager()->alterTable('xf_thread', function(Alter $table)
        {
            $table->renameColumn('is_sticky_first_post', 'bs_is_sticky_first_post');
        });
    }

    // ############################### UNINSTALL #########################

	public function uninstallStep1()
	{
        $sm = $this->schemaManager();

        foreach ($this->getAlterTables() AS $tableName => $closure)
        {
            $sm->alterTable($tableName, $closure[1]);
        }
	}

    // ############################# TABLE / DATA DEFINITIONS ##############################

    protected function getAlterTables()
    {
        $tables = [];

        $tables['xf_forum'] =
        [
            function(Alter $table)
            {
                $table->addColumn('bs_is_sticky_first_post', 'tinyint', 3)->setDefault(0);
                $table->addKey('bs_is_sticky_first_post');
            },
            function(Alter $table)
            {
                $table->dropColumns('bs_is_sticky_first_post');
            }
        ];

        $tables['xf_thread'] =
        [
            function(Alter $table)
            {
                $table->addColumn('bs_is_sticky_first_post', 'tinyint', 3)->setDefault(0);
                $table->addKey('bs_is_sticky_first_post');
            },
            function(Alter $table)
            {
                $table->dropColumns('bs_is_sticky_first_post');
            }
        ];

        return $tables;
    }
}